/// <reference types="bn.js" />
import { BN, BorshAccountsCoder, Idl } from "@project-serum/anchor";
import { PublicKey } from "@solana/web3.js";
import { PropeasyProgram } from "../artifacts/propeasy_program";
import BigNumber from "bignumber.js";
export type PropeasyType = PropeasyProgram;
export declare const PropeasyIDL: Idl;
export declare const accountsCoder: BorshAccountsCoder<string>;
export declare enum AccountName {
    Platform = "PlatformState",
    Property = "PropertyState",
    Locker = "LockerState",
    BurnRole = "BurnRoleState",
    Burn = "BurnState",
    Vesting = "VestingState"
}
export type PlatformData = {
    admin: PublicKey;
    purchaseMintAccount: PublicKey;
    platformMintAccount: PublicKey;
    bump: number[];
};
export type PrivateSaleInfo = {
    startTime: BN;
    endTime: BN;
    supplyAmount: BN;
    tokenPrice: BN;
    minimumPurchaseAmount: BN;
    totalPurchasedAmount: BN;
    commissionAmount: BN;
    referralCommissionAmount: BN;
    discountPercentage: number;
    tgePercentage: number;
    unlockPeriod: BN;
    unlockDuration: BN;
    minimumPlatformAmount: BN;
};
export type PublicSaleInfo = {
    startTime: BN;
    endTime: BN;
    supplyAmount: BN;
    tokenPrice: BN;
    minimumPurchaseAmount: BN;
    totalPurchasedAmount: BN;
    commissionAmount: BN;
    commissionBoostAmount: BN;
    referralCommissionAmount: BN;
    referralCommissionBoostAmount: BN;
    referralCommissionBoostThreshold: BN;
};
export type PropertyData = {
    privateSaleInfo: PrivateSaleInfo;
    publicSaleInfo: PublicSaleInfo;
    propertyMintAccount: PublicKey;
    bump: number[];
};
export type UiPrivateSaleInfo = {
    startTime: number;
    endTime: number;
    supplyAmount: BigNumber;
    tokenPrice: BigNumber;
    minimumPurchaseAmount: BigNumber;
    totalPurchasedAmount: BigNumber;
    commissionAmount: BigNumber;
    referralCommissionAmount: BigNumber;
    discountPercentage: number;
    tgePercentage: number;
    unlockPeriod: number;
    unlockDuration: number;
    minimumPlatformAmount: BigNumber;
};
export type UiPublicSaleInfo = {
    startTime: number;
    endTime: number;
    supplyAmount: BigNumber;
    tokenPrice: BigNumber;
    minimumPurchaseAmount: BigNumber;
    totalPurchasedAmount: BigNumber;
    commissionAmount: BigNumber;
    commissionBoostAmount: BigNumber;
    referralCommissionAmount: BigNumber;
    referralCommissionBoostAmount: BigNumber;
    referralCommissionBoostThreshold: BigNumber;
};
export type UiPropertyData = {
    privateSaleInfo: UiPrivateSaleInfo;
    publicSaleInfo: UiPublicSaleInfo;
    propertyMintAccount: PublicKey;
    totalSupply: BigNumber;
    bump: number[];
};
export type LockerData = {
    privateSaleClaimedAmount: BN;
    privateSaleTotalClaimableAmount: BN;
    publicSaleTotalAmount: BN;
};
export type UiLockerData = {
    privateSaleClaimedAmount: BigNumber;
    privateSaleTotalClaimableAmount: BigNumber;
    privateSaleCurrentClaimableAmount: BigNumber;
    privateSaleUnlockEndtime: number;
    publicSaleTotalAmount: BigNumber;
    nextUnlockTimestamp: number;
};
export type VestingData = {
    isPublicSaleClaimed: boolean;
    cliffDuration: BN;
    vestingDuration: BN;
    unlockPeriod: BN;
    totalVestingAmount: BN;
    claimedAmount: BN;
    claimedTimestamp: BN;
};
export type UiVestingData = {
    isPublicSaleClaimed: boolean;
    cliffDuration: number;
    vestingDuration: number;
    unlockPeriod: number;
    totalVestingAmount: BigNumber;
    claimedTimestamp: number;
    publicSaleClaimedAmount: BigNumber;
    publicSaleTotalClaimableAmount: BigNumber;
    publicSaleCurrentClaimableAmount: BigNumber;
    publicSaleUnlockEndTime: number;
    nextUnlockTimestamp: number;
};
export type TokenPurchasedEventData = {
    user: PublicKey;
    propertyState: PublicKey;
    propertyMintAccount: PublicKey;
    tokenPrice: BN;
    saleType: number;
    purchasedAmount: BN;
    propertyAmount: BN;
    purchasedTimestamp: BN;
    referrer: PublicKey;
    individualCommissionAmount: BN;
};
export type UiTokenPurchasedEventData = {
    user: PublicKey;
    propertyState: PublicKey;
    propertyMintAccount: PublicKey;
    tokenPrice: BigNumber;
    saleType: number;
    purchasedAmount: BigNumber;
    propertyAmount: BigNumber;
    purchasedTimestamp: number;
    referrer: PublicKey;
    individualCommissionAmount: BigNumber;
};
export type TokenClaimedEventData = {
    user: PublicKey;
    propertyState: PublicKey;
    propertyMintAccount: PublicKey;
    claimedAmount: BN;
    claimedTimestamp: BN;
};
export type UiTokenClaimedEventData = {
    user: PublicKey;
    propertyState: PublicKey;
    propertyMintAccount: PublicKey;
    claimedAmount: BigNumber;
    claimedTimestamp: number;
};
export type BurnRoleData = {
    burner: PublicKey;
    hasRole: boolean;
};
export type UiBurnRoleData = {
    burner: PublicKey;
    hasRole: boolean;
};
export type BurnData = {
    bump: number[];
    platform: PublicKey;
    mint: PublicKey;
    amountPerPeriod: BN;
    period: BN;
    lastSwapAndBurnTime: BN;
    totalBurned: BN;
};
export type UiBurnData = {
    bump: number[];
    platform: PublicKey;
    mint: PublicKey;
    amountPerPeriod: BigNumber;
    period: number;
    lastSwapAndBurnTime: number;
    totalBurned: BigNumber;
};
